@@ -8,6 +8,7 @@
 
 #include "commandoptions.h"
 
+#include "config-kalarm.h"
 #include "functions.h"
 #include "kamail.h"
 #include "preferences.h"
@@ -59,7 +60,7 @@ enum Option
     REMINDER,
     REMINDER_ONCE,
     REPEAT,
-#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_TEXT_TO_SPEECH_SUPPORT
     SPEAK,
 #endif
     SUBJECT,
@@ -245,7 +246,7 @@ QStringList CommandOptions::setOptions(QCommandLineParser* parser, const QString
               = new QCommandLineOption(QStringList{QStringLiteral("r"), QStringLiteral("repeat")},
                                        i18n("Number of times to repeat alarm (including initial occasion)"),
                                        QStringLiteral("count"));
-#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_TEXT_TO_SPEECH_SUPPORT
     mOptions[SPEAK]
               = new QCommandLineOption(QStringList{QStringLiteral("s"), QStringLiteral("speak")},
                                        i18n("Speak the message when it is displayed"));
@@ -477,7 +478,7 @@ void CommandOptions::process()
     d->checkEditType(EditAlarmDlg::DISPLAY, EditAlarmDlg::AUDIO, PLAY);
     d->checkEditType(EditAlarmDlg::DISPLAY, EditAlarmDlg::AUDIO, PLAY_REPEAT);
     d->checkEditType(EditAlarmDlg::DISPLAY, EditAlarmDlg::AUDIO, VOLUME);
-#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_TEXT_TO_SPEECH_SUPPORT
     d->checkEditType(EditAlarmDlg::DISPLAY, SPEAK);
 #endif
     d->checkEditType(EditAlarmDlg::DISPLAY, BEEP);
@@ -631,7 +632,7 @@ void CommandOptions::process()
                     d->setErrorIncompatible(PLAY, PLAY_REPEAT);
                 if (mParser->isSet(*mOptions.at(BEEP)))
                     d->setErrorIncompatible(BEEP, opt);
-#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_TEXT_TO_SPEECH_SUPPORT
                 else if (mParser->isSet(*mOptions.at(SPEAK)))
                     d->setErrorIncompatible(SPEAK, opt);
 #endif
@@ -647,7 +648,7 @@ void CommandOptions::process()
             }
             else if (mParser->isSet(*mOptions.at(VOLUME)))
                 d->setErrorRequires(VOLUME, PLAY, PLAY_REPEAT);
-#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_TEXT_TO_SPEECH_SUPPORT
             if (mParser->isSet(*mOptions.at(SPEAK)))
             {
                 if (mParser->isSet(*mOptions.at(BEEP)))
@@ -706,7 +707,7 @@ void CommandOptions::process()
                 mFlags |= KAEvent::AUTO_CLOSE;
             if (mParser->isSet(*mOptions.at(BEEP)))
                 mFlags |= KAEvent::BEEP;
-#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_TEXT_TO_SPEECH_SUPPORT
             if (mParser->isSet(*mOptions.at(SPEAK)))
                 mFlags |= KAEvent::SPEAK;
 #endif
@@ -769,7 +770,7 @@ void CommandOptions::process()
                 errors << d->optionName(REMINDER);
             if (mParser->isSet(*mOptions.at(REMINDER_ONCE)))
                 errors << d->optionName(REMINDER_ONCE);
-#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_TEXT_TO_SPEECH_SUPPORT
             if (mParser->isSet(*mOptions.at(SPEAK)))
                 errors << d->optionName(SPEAK);
 #endif
