@@ -111,7 +111,7 @@ protected:
     void            showMainPage();
     bool            isTemplate() const         { return mTemplate; }
     bool            isNewAlarm() const         { return mNewAlarm; }
-    bool            dateOnly() const;
+    bool            isDateOnly() const;
     bool            isTimedRecurrence() const;
     bool            showingMore() const        { return mShowingMore; }
     Reminder*       reminder() const           { return mReminder; }
@@ -131,7 +131,7 @@ private Q_SLOTS:
     void            slotShowMainPage();
     void            slotShowRecurrenceEdit();
     void            slotAnyTimeToggled(bool anyTime);
-    void            slotTemplateTimeType(QAbstractButton*);
+    void            slotTemplateTimeType(QAbstractButton*, QAbstractButton*);
     void            slotSetSubRepetition();
     void            slotResize();
     void            focusFixTimer();
