@@ -15,8 +15,8 @@
 #include "eventid.h"
 #include "kalarmcalendar/kaevent.h"
 
+#include <QList>
 #include <QString>
-#include <QVector>
 
 using namespace KAlarmCal;
 
@@ -55,7 +55,7 @@ struct UpdateResult
 {
     UpdateStatus  status;   // status code
     QString       message;  // error message if any
-    QVector<int>  failed;   // indexes to events whose update failed
+    QList<int>    failed;   // indexes to events whose update failed
 
     UpdateResult() : status(UPDATE_OK) {}
     explicit UpdateResult(UpdateStatus s, const QString& m = QString()) : status(s), message(m) {}
@@ -73,39 +73,39 @@ struct UpdateResult
 QString i18n_act_StopPlay();      // text of Stop Play action
 
 /** Display a main window with the specified event selected */
-MainWindow*         displayMainWindowSelected(const QString& eventId);
+MainWindow*    displayMainWindowSelected(const QString& eventId);
 
-bool                editNewAlarm(const QString& templateName, QWidget* parent = nullptr);
-void                editNewAlarm(EditAlarmDlg::Type, QWidget* parent = nullptr);
-void                editNewAlarm(EditAlarmDlg::Type, const QDate& startDate, QWidget* parent = nullptr);
-void                editNewAlarm(KAEvent::SubAction, QWidget* parent = nullptr, const AlarmText* = nullptr);
-void                editNewAlarm(const KAEvent& preset, QWidget* parent = nullptr);
-void                editNewAlarm(const KAEvent& preset, const QDate& startDate, QWidget* parent = nullptr);
-void                editAlarm(KAEvent&, QWidget* parent = nullptr);
-bool                editAlarmById(const EventId& eventID, QWidget* parent = nullptr);
-void                updateEditedAlarm(EditAlarmDlg*, KAEvent&, Resource&);
-void                viewAlarm(const KAEvent&, QWidget* parent = nullptr);
-void                editNewTemplate(EditAlarmDlg::Type, QWidget* parent = nullptr);
-void                editNewTemplate(const KAEvent& preset, QWidget* parent = nullptr);
-void                editTemplate(const KAEvent&, QWidget* parent = nullptr);
-void                execNewAlarmDlg(EditAlarmDlg*, const QDate& startDate = QDate());
+bool           editNewAlarm(const QString& templateName, QWidget* parent = nullptr);
+void           editNewAlarm(EditAlarmDlg::Type, QWidget* parent = nullptr);
+void           editNewAlarm(EditAlarmDlg::Type, const QDate& startDate, QWidget* parent = nullptr);
+void           editNewAlarm(KAEvent::SubAction, QWidget* parent = nullptr, const AlarmText* = nullptr);
+void           editNewAlarm(const KAEvent& preset, QWidget* parent = nullptr);
+void           editNewAlarm(const KAEvent& preset, const QDate& startDate, QWidget* parent = nullptr);
+void           editAlarm(KAEvent&, QWidget* parent = nullptr);
+bool           editAlarmById(const EventId& eventID, QWidget* parent = nullptr);
+void           updateEditedAlarm(EditAlarmDlg*, KAEvent&, Resource&);
+void           viewAlarm(const KAEvent&, QWidget* parent = nullptr);
+void           editNewTemplate(EditAlarmDlg::Type, QWidget* parent = nullptr);
+void           editNewTemplate(const KAEvent& preset, QWidget* parent = nullptr);
+void           editTemplate(const KAEvent&, QWidget* parent = nullptr);
+void           execNewAlarmDlg(EditAlarmDlg*, const QDate& startDate = QDate());
 /** Create a "New From Template" QAction */
-KToggleAction*      createAlarmEnableAction(QObject* parent);
-QAction*            createStopPlayAction(QObject* parent);
-KToggleAction*      createSpreadWindowsAction(QObject* parent);
+KToggleAction* createAlarmEnableAction(QObject* parent);
+QAction*       createStopPlayAction(QObject* parent);
+KToggleAction* createSpreadWindowsAction(QObject* parent);
 /** Returns a list of all alarm templates.
  *  If shell commands are disabled, command alarm templates are omitted.
  */
-QVector<KAEvent>    templateList();
-void                outputAlarmWarnings(QWidget* parent, const KAEvent* = nullptr);
-void                refreshAlarms();
-void                refreshAlarmsIfQueued();    // must only be called from KAlarmApp::processQueue()
+QList<KAEvent> templateList();
+void           outputAlarmWarnings(QWidget* parent, const KAEvent* = nullptr);
+void           refreshAlarms();
+void           refreshAlarmsIfQueued();    // must only be called from KAlarmApp::processQueue()
 
-QStringList         dontShowErrors(const EventId&);
-bool                dontShowErrors(const EventId&, const QString& tag);
-void                setDontShowErrors(const EventId&, const QStringList& tags = QStringList());
-void                setDontShowErrors(const EventId&, const QString& tag);
-void                setDontShowErrors(const QString& eventId, const QString& tag);
+QStringList    dontShowErrors(const EventId&);
+bool           dontShowErrors(const EventId&, const QString& tag);
+void           setDontShowErrors(const EventId&, const QStringList& tags = QStringList());
+void           setDontShowErrors(const EventId&, const QString& tag);
+void           setDontShowErrors(const QString& eventId, const QString& tag);
 
 enum         // 'options' parameter values for addEvent(). May be OR'ed together.
 {
@@ -134,7 +134,8 @@ UpdateResult addEvent(KAEvent& event, Resource& resource, QWidget* msgParent = n
  *                    message.
  *  @return  Success status; if >= UPDATE_FAILED, all new alarms have been discarded.
  */
-UpdateResult addEvents(QVector<KAEvent>& events, Resource& resource, QWidget* msgParent = nullptr, bool allowKOrgUpdate = true, bool showKOrgErr = true);
+UpdateResult addEvents(QList<KAEvent>& events, Resource& resource, QWidget* msgParent = nullptr,
+                       bool allowKOrgUpdate = true, bool showKOrgErr = true);
 
 /** Save the event in the archived calendar.
  *  The event's ID is changed to an archived ID if necessary.
@@ -207,7 +208,7 @@ UpdateResult deleteEvent(KAEvent& event, Resource& resource, bool archive = true
 
 /** Delete alarms from the resources.
  *  If the events are archived, the events' IDs are changed to archived IDs if necessary.
- *  @param event      Event to delete.
+ *  @param events     Events to delete.
  *  @param resource   Resource to delete event from. If invalid, and all events
  *                    are found in the same resource, this is updated to the
  *                    resource which contained the events.
@@ -215,7 +216,8 @@ UpdateResult deleteEvent(KAEvent& event, Resource& resource, bool archive = true
  *                    message.
  *  @return  Success status; if >= UPDATE_FAILED, all deletions have been discarded.
  */
-UpdateResult deleteEvents(QVector<KAEvent>&, Resource& resource, bool archive = true, QWidget* msgParent = nullptr, bool showKOrgErr = true);
+UpdateResult deleteEvents(QList<KAEvent>& events, Resource& resource, bool archive = true,
+                          QWidget* msgParent = nullptr, bool showKOrgErr = true);
 
 /** Delete templates from the resources.
  *  @param event      Event to delete.
@@ -254,7 +256,8 @@ UpdateResult reactivateEvent(KAEvent& event, Resource& resource, QWidget* msgPar
  *                    message.
  *  @return  Success status; if >= UPDATE_FAILED, all reactivated events have been discarded.
  */
-UpdateResult reactivateEvents(QVector<KAEvent>& events, QVector<int>& ineligibleIndexes, Resource& resource, QWidget* msgParent = nullptr, bool showKOrgErr = true);
+UpdateResult reactivateEvents(QList<KAEvent>& events, QList<int>& ineligibleIndexes,
+                              Resource& resource, QWidget* msgParent = nullptr, bool showKOrgErr = true);
 
 /** Enable or disable alarms.
  *  The new events will have the same event IDs as the old ones.
@@ -268,15 +271,15 @@ UpdateResult reactivateEvents(QVector<KAEvent>& events, QVector<int>& ineligible
  *           least one event has been successfully changed, but will be lost
  *           when its resource is reloaded.
  */
-UpdateResult enableEvents(QVector<KAEvent>& events, bool enable, QWidget* msgParent = nullptr);
+UpdateResult enableEvents(QList<KAEvent>& events, bool enable, QWidget* msgParent = nullptr);
 
 /** Return whether an event is read-only.
  *  This depends on whether the event or its resource is read-only.
  */
 bool eventReadOnly(const QString& eventId);
 
-QVector<KAEvent>    getSortedActiveEvents(QObject* parent, AlarmListModel** model = nullptr);
-void                purgeArchive(int purgeDays);    // must only be called from KAlarmApp::processQueue()
+QList<KAEvent> getSortedActiveEvents(QObject* parent, AlarmListModel** model = nullptr);
+void           purgeArchive(int purgeDays);    // must only be called from KAlarmApp::processQueue()
 
 /** Prompt the user for an external calendar file to import alarms from,
  *  and merge them into a resource. If the resource is invalid, the events
@@ -299,14 +302,14 @@ bool importAlarms(Resource& resource, QWidget* parent);
  *  @return  true if all alarms in the calendar were successfully exported;
  *           false if any alarms failed to be exported.
  */
-bool exportAlarms(const QVector<KAEvent>& events, QWidget* parent);
+bool exportAlarms(const QList<KAEvent>& events, QWidget* parent);
 
-void                displayKOrgUpdateError(QWidget* parent, UpdateError, const UpdateResult& korgError, int nAlarms = 0);
-#if ENABLE_WAKE_FROM_SUSPEND
-QStringList         checkRtcWakeConfig(bool checkEventExists = false);
-void                deleteRtcWakeConfig();
-void                cancelRtcWake(QWidget* msgParent, const QString& eventId = QString());
-bool                setRtcWakeTime(unsigned triggerTime, QWidget* parent);
+void        displayKOrgUpdateError(QWidget* parent, UpdateError, const UpdateResult& korgError, int nAlarms = 0);
+#if ENABLE_RTC_WAKE_FROM_SUSPEND
+QStringList checkRtcWakeConfig(bool checkEventExists = false);
+void        deleteRtcWakeConfig();
+void        cancelRtcWake(QWidget* msgParent, const QString& eventId = QString());
+bool        setRtcWakeTime(unsigned triggerTime, QWidget* parent);
 #endif
 
 /** Extract dragged and dropped Akonadi RFC822 message data.
@@ -320,14 +323,14 @@ bool                setRtcWakeTime(unsigned triggerTime, QWidget* parent);
  */
 bool dropAkonadiEmail(const QMimeData* data, QUrl& url, AlarmText& alarmText);
 
-bool                convertTimeString(const QByteArray& timeString, KADateTime& dateTime,
-                                  const KADateTime& defaultDt = KADateTime(), bool allowTZ = true);
-KADateTime          applyTimeZone(const QString& tzstring, const QDate& date, const QTime& time,
-                                   bool haveTime, const KADateTime& defaultDt = KADateTime());
+bool        convertTimeString(const QByteArray& timeString, KADateTime& dateTime,
+                              const KADateTime& defaultDt = KADateTime(), bool allowTZ = true);
+KADateTime  applyTimeZone(const QString& tzstring, const QDate& date, const QTime& time,
+                          bool haveTime, const KADateTime& defaultDt = KADateTime());
 
 #ifndef NDEBUG
-void                setTestModeConditions();
-void                setSimulatedSystemTime(const KADateTime&);
+void        setTestModeConditions();
+void        setSimulatedSystemTime(const KADateTime&);
 #endif
 
 } // namespace KAlarm
