@@ -1,7 +1,7 @@
 /*
  *  packedlayout.h  -  layout to pack items into rows
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2007-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -43,7 +43,7 @@ public:
     QSize            sizeHint() const  override { return minimumSize(); }
     QSize            minimumSize() const override;
     Qt::Orientations expandingDirections() const override  { return Qt::Vertical | Qt::Horizontal; }
-    void             invalidate() override  { mWidthCached = mHeightCached = false; }
+    void             invalidate() override  { mWidthCached = mHeightCached = 0; }
 
 private:
     int              arrange(const QRect&, bool set) const;
@@ -55,7 +55,7 @@ private:
     int                 mHorizontalSpacing {-1};   // default = not set
     int                 mVerticalSpacing {-1};     // default = not set
     mutable int         mWidthCached {0};
-    mutable int         mHeightCached;
+    mutable int         mHeightCached {0};
 };
 
 // vim: et sw=4:
