@@ -1,7 +1,7 @@
 /*
  *  recurrenceedit.cpp  -  widget to edit the event's recurrence definition
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2002-2022 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2002-2024 David Jarvie <djarvie@kde.org>
  *
  *  Based originally on KOrganizer module koeditorrecurrence.cpp,
  *  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
@@ -90,13 +90,13 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     vlayout->setContentsMargins(0, 0, 0, 0);
     hlayout->addLayout(vlayout);
     mRuleButtonGroup = new ButtonGroup(recurGroup);
-    connect(mRuleButtonGroup, &ButtonGroup::buttonSet, this, &RecurrenceEdit::periodClicked);
-    connect(mRuleButtonGroup, &ButtonGroup::buttonSet, this, &RecurrenceEdit::contentsChanged);
+    connect(mRuleButtonGroup, &ButtonGroup::selectionChanged, this, &RecurrenceEdit::periodClicked);
+    connect(mRuleButtonGroup, &ButtonGroup::selectionChanged, this, &RecurrenceEdit::contentsChanged);
 
     mNoneButton = new RadioButton(i18n_combo_NoRecur(), recurGroup);
     mNoneButton->setReadOnly(mReadOnly);
     mNoneButton->setWhatsThis(i18nc("@info:whatsthis", "Do not repeat the alarm"));
-    mRuleButtonGroup->addButton(mNoneButton);
+    mRuleButtonGroup->insertButton(mNoneButton);
     vlayout->addWidget(mNoneButton);
 
     mAtLoginButton = new RadioButton(i18n_combo_AtLogin(), recurGroup);
@@ -104,37 +104,37 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     mAtLoginButton->setWhatsThis(xi18nc("@info:whatsthis",
                                       "<para>Trigger the alarm at the specified date/time and at every login until then.</para>"
                                       "<para>Note that it will also be triggered any time <application>KAlarm</application> is restarted.</para>"));
-    mRuleButtonGroup->addButton(mAtLoginButton);
+    mRuleButtonGroup->insertButton(mAtLoginButton);
     vlayout->addWidget(mAtLoginButton);
 
     mSubDailyButton = new RadioButton(i18n_combo_HourlyMinutely(), recurGroup);
     mSubDailyButton->setReadOnly(mReadOnly);
     mSubDailyButton->setWhatsThis(i18nc("@info:whatsthis", "Repeat the alarm at hourly/minutely intervals"));
-    mRuleButtonGroup->addButton(mSubDailyButton);
+    mRuleButtonGroup->insertButton(mSubDailyButton);
     vlayout->addWidget(mSubDailyButton);
 
     mDailyButton = new RadioButton(i18n_combo_Daily(), recurGroup);
     mDailyButton->setReadOnly(mReadOnly);
     mDailyButton->setWhatsThis(i18nc("@info:whatsthis", "Repeat the alarm at daily intervals"));
-    mRuleButtonGroup->addButton(mDailyButton);
+    mRuleButtonGroup->insertButton(mDailyButton);
     vlayout->addWidget(mDailyButton);
 
     mWeeklyButton = new RadioButton(i18n_combo_Weekly(), recurGroup);
     mWeeklyButton->setReadOnly(mReadOnly);
     mWeeklyButton->setWhatsThis(i18nc("@info:whatsthis", "Repeat the alarm at weekly intervals"));
-    mRuleButtonGroup->addButton(mWeeklyButton);
+    mRuleButtonGroup->insertButton(mWeeklyButton);
     vlayout->addWidget(mWeeklyButton);
 
     mMonthlyButton = new RadioButton(i18n_combo_Monthly(), recurGroup);
     mMonthlyButton->setReadOnly(mReadOnly);
     mMonthlyButton->setWhatsThis(i18nc("@info:whatsthis", "Repeat the alarm at monthly intervals"));
-    mRuleButtonGroup->addButton(mMonthlyButton);
+    mRuleButtonGroup->insertButton(mMonthlyButton);
     vlayout->addWidget(mMonthlyButton);
 
     mYearlyButton = new RadioButton(i18n_combo_Yearly(), recurGroup);
     mYearlyButton->setReadOnly(mReadOnly);
     mYearlyButton->setWhatsThis(i18nc("@info:whatsthis", "Repeat the alarm at annual intervals"));
-    mRuleButtonGroup->addButton(mYearlyButton);
+    mRuleButtonGroup->insertButton(mYearlyButton);
     vlayout->addWidget(mYearlyButton);
     vlayout->addStretch();    // top-adjust the interval radio buttons
 
@@ -193,14 +193,14 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     mRangeButtonBox = new QGroupBox(i18nc("@title:group", "Recurrence End"), this);
     topLayout->addWidget(mRangeButtonBox);
     mRangeButtonGroup = new ButtonGroup(mRangeButtonBox);
-    connect(mRangeButtonGroup, &ButtonGroup::buttonSet, this, &RecurrenceEdit::rangeTypeClicked);
-    connect(mRangeButtonGroup, &ButtonGroup::buttonSet, this, &RecurrenceEdit::contentsChanged);
+    connect(mRangeButtonGroup, &ButtonGroup::selectionChanged, this, &RecurrenceEdit::rangeTypeClicked);
+    connect(mRangeButtonGroup, &ButtonGroup::selectionChanged, this, &RecurrenceEdit::contentsChanged);
 
     vlayout = new QVBoxLayout(mRangeButtonBox);
     mNoEndDateButton = new RadioButton(i18nc("@option:radio", "No end"), mRangeButtonBox);
     mNoEndDateButton->setReadOnly(mReadOnly);
     mNoEndDateButton->setWhatsThis(i18nc("@info:whatsthis", "Repeat the alarm indefinitely"));
-    mRangeButtonGroup->addButton(mNoEndDateButton);
+    mRangeButtonGroup->insertButton(mNoEndDateButton);
     vlayout->addWidget(mNoEndDateButton, 1, Qt::AlignLeft);
     QSize size = mNoEndDateButton->size();
 
@@ -210,7 +210,7 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     mRepeatCountButton = new RadioButton(i18nc("@option:radio", "End after:"), mRangeButtonBox);
     mRepeatCountButton->setReadOnly(mReadOnly);
     mRepeatCountButton->setWhatsThis(i18nc("@info:whatsthis", "Repeat the alarm for the number of times specified"));
-    mRangeButtonGroup->addButton(mRepeatCountButton);
+    mRangeButtonGroup->insertButton(mRepeatCountButton);
     mRepeatCountEntry = new SpinBox(1, 9999, mRangeButtonBox);
     mRepeatCountEntry->setSingleShiftStep(10);
     mRepeatCountEntry->setSelectOnStep(false);
@@ -235,7 +235,7 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     mEndDateButton->setWhatsThis(
           xi18nc("@info:whatsthis", "<para>Repeat the alarm until the date/time specified.</para>"
                 "<para><note>This applies to the main recurrence only. It does not limit any sub-repetition which will occur regardless after the last main recurrence.</note></para>"));
-    mRangeButtonGroup->addButton(mEndDateButton);
+    mRangeButtonGroup->insertButton(mEndDateButton);
     mEndDateEdit = new KDateComboBox(mRangeButtonBox);
     mEndDateEdit->setOptions(mReadOnly ? KDateComboBox::Options{} : KDateComboBox::EditDate | KDateComboBox::SelectDate | KDateComboBox::DatePicker);
     static const QString tzText = i18nc("@info", "This uses the same time zone as the start time.");
@@ -294,7 +294,7 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
         vlayout->setContentsMargins(0, 0, 0, 0);
         hlayout->addLayout(vlayout);
         mExceptionDateEdit = new KDateComboBox(mExceptionGroup);
-        mExceptionDateEdit->setOptions(mReadOnly ? KDateComboBox::Options{} : KDateComboBox::EditDate | KDateComboBox::SelectDate | KDateComboBox::DatePicker);
+        mExceptionDateEdit->setOptions(KDateComboBox::EditDate | KDateComboBox::SelectDate | KDateComboBox::DatePicker);
         mExceptionDateEdit->setDate(KADateTime::currentLocalDate());
         mExceptionDateEdit->setWhatsThis(i18nc("@info:whatsthis",
               "Enter a date to insert in the exceptions list. "
@@ -388,9 +388,10 @@ QWidget* RecurrenceEdit::checkData(const KADateTime& startDateTime, QString& err
 }
 
 /******************************************************************************
-* Called when a recurrence period radio button is clicked.
+* Called when a recurrence period radio button is clicked, or the selection
+* changes.
 */
-void RecurrenceEdit::periodClicked(QAbstractButton* button)
+void RecurrenceEdit::periodClicked(QAbstractButton*, QAbstractButton* button)
 {
     const RepeatType oldType = mRuleButtonType;
     const bool none     = (button == mNoneButton);
@@ -460,13 +461,14 @@ void RecurrenceEdit::periodClicked(QAbstractButton* button)
 
 void RecurrenceEdit::slotAnyTimeToggled(bool on)
 {
-    QAbstractButton* button = mRuleButtonGroup->checkedButton();
+    const QAbstractButton* button = mRuleButtonGroup->checkedButton();
     mEndTimeEdit->setEnabled((button == mAtLoginButton && !on)
                          ||  (button == mSubDailyButton && mEndDateButton->isChecked()));
 }
 
 /******************************************************************************
-* Called when a recurrence range type radio button is clicked.
+* Called when a recurrence range type radio button is clicked, or the selection
+* changes.
 */
 void RecurrenceEdit::rangeTypeClicked()
 {
@@ -765,10 +767,10 @@ void RecurrenceEdit::set(const KAEvent& event)
         return;
     }
     mNoneButton->setChecked(true);
-    KARecurrence* recurrence = event.recurrence();
-    if (!recurrence)
+    const KARecurrence& recurrence = event.recurrence();
+    if (!recurrence.recurs())
         return;
-    const KARecurrence::Type rtype = recurrence->type();
+    const KARecurrence::Type rtype = recurrence.type();
     switch (rtype)
     {
         case KARecurrence::MINUTELY:
@@ -778,7 +780,7 @@ void RecurrenceEdit::set(const KAEvent& event)
         case KARecurrence::DAILY:
         {
             mDailyButton->setChecked(true);
-            const QBitArray rDays = recurrence->days();
+            const QBitArray rDays = recurrence.days();
             if (rDays.count(true))
                 mDailyRule->setDays(rDays);
             else
@@ -788,20 +790,20 @@ void RecurrenceEdit::set(const KAEvent& event)
         case KARecurrence::WEEKLY:
         {
             mWeeklyButton->setChecked(true);
-            const QBitArray rDays = recurrence->days();
+            const QBitArray rDays = recurrence.days();
             mWeeklyRule->setDays(rDays);
             break;
         }
         case KARecurrence::MONTHLY_POS:    // on nth (Tuesday) of the month
         {
-            const QList<RecurrenceRule::WDayPos> posns = recurrence->monthPositions();
+            const QList<RecurrenceRule::WDayPos> posns = recurrence.monthPositions();
             int i = posns.first().pos();
             if (!i)
             {
                 // It's every (Tuesday) of the month. Convert to a weekly recurrence
                 // (but ignoring any non-every xxxDay positions).
                 mWeeklyButton->setChecked(true);
-                mWeeklyRule->setFrequency(recurrence->frequency());
+                mWeeklyRule->setFrequency(recurrence.frequency());
                 QBitArray rDays(7);
                 for (const RecurrenceRule::WDayPos& posn : posns)
                 {
@@ -818,7 +820,7 @@ void RecurrenceEdit::set(const KAEvent& event)
         case KARecurrence::MONTHLY_DAY:     // on nth day of the month
         {
             mMonthlyButton->setChecked(true);
-            const QList<int> rmd = recurrence->monthDays();
+            const QList<int> rmd = recurrence.monthDays();
             const int day = (rmd.isEmpty()) ? event.mainDateTime().date().day() : rmd.first();
             mMonthlyRule->setDate(day);
             break;
@@ -829,29 +831,29 @@ void RecurrenceEdit::set(const KAEvent& event)
             if (rtype == KARecurrence::ANNUAL_DATE)
             {
                 mYearlyButton->setChecked(true);
-                const QList<int> rmd = recurrence->monthDays();
+                const QList<int> rmd = recurrence.monthDays();
                 const int day = (rmd.isEmpty()) ? event.mainDateTime().date().day() : rmd.first();
                 mYearlyRule->setDate(day);
-                mYearlyRule->setFeb29Type(recurrence->feb29Type());
+                mYearlyRule->setFeb29Type(recurrence.feb29Type());
             }
             else if (rtype == KARecurrence::ANNUAL_POS)
             {
                 mYearlyButton->setChecked(true);
-                const QList<RecurrenceRule::WDayPos> posns = recurrence->yearPositions();
+                const QList<RecurrenceRule::WDayPos> posns = recurrence.yearPositions();
                 mYearlyRule->setPosition(posns.first().pos(), posns.first().day());
             }
-            mYearlyRule->setMonths(recurrence->yearMonths());
+            mYearlyRule->setMonths(recurrence.yearMonths());
             break;
         }
         default:
             return;
     }
 
-    mRule->setFrequency(recurrence->frequency());
+    mRule->setFrequency(recurrence.frequency());
 
     // Get range information
     KADateTime endtime = mCurrStartDateTime;
-    const int duration = recurrence->duration();
+    const int duration = recurrence.duration();
     if (duration == -1)
         mNoEndDateButton->setChecked(true);
     else if (duration)
@@ -862,13 +864,13 @@ void RecurrenceEdit::set(const KAEvent& event)
     else
     {
         mEndDateButton->setChecked(true);
-        endtime = recurrence->endDateTime();
+        endtime = recurrence.endDateTime();
         mEndTimeEdit->setValue(endtime.time());
     }
     mEndDateEdit->setDate(endtime.date());
 
     // Get exception information
-    mExceptionDates = event.recurrence()->exDates();
+    mExceptionDates = event.recurrence().exDates();
     std::sort(mExceptionDates.begin(), mExceptionDates.end());
     mExceptionDateList->clear();
     for (const QDate& exceptionDate : std::as_const(mExceptionDates))
@@ -909,13 +911,13 @@ void RecurrenceEdit::updateEvent(KAEvent& event, bool adjustStart)
 
     // Set up the recurrence according to the type selected
     event.startChanges();
-    QAbstractButton* button = mRuleButtonGroup->checkedButton();
+    const QAbstractButton* button = mRuleButtonGroup->checkedButton();
     event.setRepeatAtLogin(button == mAtLoginButton);
     const int frequency = mRule ? mRule->frequency() : 0;
     if (button == mSubDailyButton)
     {
-        const KADateTime endDateTime(endDate, endTime, mCurrStartDateTime.timeSpec());
-        event.setRecurMinutely(frequency, repeatCount, endDateTime);
+        const KADateTime endDt(endDate, endTime, mCurrStartDateTime.timeSpec());
+        event.setRecurMinutely(frequency, repeatCount, endDt);
     }
     else if (button == mDailyButton)
     {
@@ -984,7 +986,7 @@ void RecurrenceEdit::updateEvent(KAEvent& event, bool adjustStart)
     event.setRepetition((mRuleButtonType < SUBDAILY) ? Repetition() : mSubRepetition->repetition());
 
     // Set up exceptions
-    event.recurrence()->setExDates(mExceptionDates);
+    event.setExceptionDates(mExceptionDates);
     event.setWorkTimeOnly(mWorkTimeOnly->isChecked());
     event.setExcludeHolidays(mExcludeHolidays->isChecked());
 
@@ -1301,7 +1303,7 @@ MonthYearRule::MonthYearRule(const QString& freqText, const QString& freqWhatsTh
     mDayButton = new RadioButton(i18nc("@option:radio On day number in the month", "On day"), this);
     mDayButton->setFixedSize(mDayButton->sizeHint());
     mDayButton->setReadOnly(readOnly);
-    mButtonGroup->addButton(mDayButton);
+    mButtonGroup->insertButton(mDayButton);
     mDayButton->setWhatsThis(i18nc("@info:whatsthis", "Repeat the alarm on the selected day of the month"));
     boxLayout->addWidget(mDayButton, 0, 0);
 
@@ -1323,7 +1325,7 @@ MonthYearRule::MonthYearRule(const QString& freqText, const QString& freqWhatsTh
     mPosButton = new RadioButton(i18nc("@option:radio On the 1st Tuesday", "On the"), this);
     mPosButton->setFixedSize(mPosButton->sizeHint());
     mPosButton->setReadOnly(readOnly);
-    mButtonGroup->addButton(mPosButton);
+    mButtonGroup->insertButton(mPosButton);
     mPosButton->setWhatsThis(i18nc("@info:whatsthis", "Repeat the alarm on one day of the week, in the selected week of the month"));
     boxLayout->addWidget(mPosButton, 1, 0);
 
@@ -1362,8 +1364,8 @@ MonthYearRule::MonthYearRule(const QString& freqText, const QString& freqWhatsTh
     connect(mDayOfWeekCombo, static_cast<void (ComboBox::*)(int)>(&ComboBox::currentIndexChanged), this, &MonthYearRule::changed);
     boxLayout->addWidget(mDayOfWeekCombo, 1, 2, Qt::AlignLeft);
 
-    connect(mButtonGroup, &ButtonGroup::buttonSet, this, &MonthYearRule::clicked);
-    connect(mButtonGroup, &ButtonGroup::buttonSet, this, &MonthYearRule::changed);
+    connect(mButtonGroup, &ButtonGroup::selectionChanged, this, &MonthYearRule::clicked);
+    connect(mButtonGroup, &ButtonGroup::selectionChanged, this, &MonthYearRule::changed);
 }
 
 MonthYearRule::DayPosType MonthYearRule::type() const
@@ -1419,13 +1421,13 @@ void MonthYearRule::setPosition(int week, int dayOfWeek)
 
 void MonthYearRule::enableSelection(DayPosType type)
 {
-    const bool date = (type == DATE);
-    mDayCombo->setEnabled(date);
-    mWeekCombo->setEnabled(!date);
-    mDayOfWeekCombo->setEnabled(!date);
+    const bool dateType = (type == DATE);
+    mDayCombo->setEnabled(dateType);
+    mWeekCombo->setEnabled(!dateType);
+    mDayOfWeekCombo->setEnabled(!dateType);
 }
 
-void MonthYearRule::clicked(QAbstractButton* button)
+void MonthYearRule::clicked(QAbstractButton*, QAbstractButton* button)
 {
     enableSelection(button == mDayButton ? DATE : POS);
 }
@@ -1629,9 +1631,9 @@ QWidget* YearlyRule::validate(QString& errorMessage)
 * Called when a yearly recurrence type radio button is clicked,
 * to enable/disable month checkboxes as appropriate for the date selected.
 */
-void YearlyRule::clicked(QAbstractButton* button)
+void YearlyRule::clicked(QAbstractButton* oldButton, QAbstractButton* button)
 {
-    MonthYearRule::clicked(button);
+    MonthYearRule::clicked(oldButton, button);
     daySelected(buttonType(button) == DATE ? date() : 1);
 }
 
