@@ -1,7 +1,7 @@
 /*
  *  fileresource.cpp  -  base class for calendar resource accessed via file system
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2006-2022 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2006-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -258,7 +258,7 @@ void FileResource::editResource(QWidget* dialogParent)
 {
     switch (storageType())
     {
-        case File:
+        case Storage::File:
         {
             // Use AutoQPointer to guard against crash on application exit while
             // the dialogue is still open. It prevents double deletion (both on
@@ -289,7 +289,7 @@ void FileResource::editResource(QWidget* dialogParent)
             }
             break;
         }
-        case Directory:
+        case Storage::Directory:
             // Not currently intended to be implemented.
             break;
 
@@ -322,7 +322,7 @@ bool FileResource::load(bool readThroughCache)
     if (!mSettings  ||  !mSettings->isValid())
     {
         qCWarning(KALARM_LOG) << "FileResource::load: Resource not configured!" << displayName();
-        errorMessage = i18nc("@info", "Resource is not configured.");
+        errorMessage = i18nc("@info", "Calendar is not configured.");
     }
     else if (mStatus == Status::Closed)
         qCWarning(KALARM_LOG) << "FileResource::load: Resource closed!" << displayName();
@@ -379,7 +379,7 @@ void FileResource::loaded(bool success, QHash<QString, KAEvent>& newEvents, cons
         // These are stored in the KAlarm config file, not the alarm
         // calendar, since they are specific to the user's local system.
         bool changed = false;
-        QHash<QString, KAEvent::CmdErrType> cmdErrors = mSettings->commandErrors();
+        QHash<QString, KAEvent::CmdErr> cmdErrors = mSettings->commandErrors();
         for (auto errit = cmdErrors.begin();  errit != cmdErrors.end();  )
         {
             auto evit = newEvents.find(errit.key());
@@ -452,14 +452,14 @@ bool FileResource::checkSave()
     if (!mSettings  ||  !mSettings->isValid())
     {
         qCWarning(KALARM_LOG) << "FileResource::checkSave: FileResource not configured!" << displayName();
-        errorMessage = i18nc("@info", "Resource is not configured.");
+        errorMessage = i18nc("@info", "Calendar is not configured.");
     }
     else if (!isValid()  ||  !mSettings->enabledTypes())
         return false;
     else if (readOnly())
     {
         qCWarning(KALARM_LOG) << "FileResource::checkSave: Read-only resource!" << displayName();
-        errorMessage = i18nc("@info", "Resource is read-only.");
+        errorMessage = i18nc("@info", "Calendar is read-only.");
     }
     else if (mCompatibility != KACalendar::Current)
     {
@@ -503,9 +503,9 @@ bool FileResource::addEvent(const KAEvent& event)
         {
             // Add this event's command error to the settings.
             if (event.category() == CalEvent::ACTIVE
-            &&  event.commandError() != KAEvent::CMD_NO_ERROR)
+            &&  event.commandError() != KAEvent::CmdErr::None)
             {
-                QHash<QString, KAEvent::CmdErrType> cmdErrors = mSettings->commandErrors();
+                QHash<QString, KAEvent::CmdErr> cmdErrors = mSettings->commandErrors();
                 cmdErrors[event.id()] = event.commandError();
                 mSettings->setCommandErrors(cmdErrors);
             }
@@ -577,7 +577,7 @@ bool FileResource::deleteEvent(const KAEvent& event)
 
         if (mSettings  &&  mSettings->isEnabled(CalEvent::ACTIVE))
         {
-            QHash<QString, KAEvent::CmdErrType> cmdErrors = mSettings->commandErrors();
+            QHash<QString, KAEvent::CmdErr> cmdErrors = mSettings->commandErrors();
             if (cmdErrors.remove(event.id()))
                 mSettings->setCommandErrors(cmdErrors);
         }
@@ -597,9 +597,9 @@ void FileResource::handleCommandErrorChange(const KAEvent& event)
         return;
     // Update command errors held in the settings, if appropriate.
     bool changed = false;
-    QHash<QString, KAEvent::CmdErrType> cmdErrors = mSettings->commandErrors();
+    QHash<QString, KAEvent::CmdErr> cmdErrors = mSettings->commandErrors();
     if (event.category() != CalEvent::ACTIVE
-    ||  event.commandError() == KAEvent::CMD_NO_ERROR)
+    ||  event.commandError() == KAEvent::CmdErr::None)
     {
         if (cmdErrors.remove(event.id()))
             changed = true;
@@ -722,4 +722,6 @@ void FileResource::setStatus(Status newStatus)
     }
 }
 
+#include "moc_fileresource.cpp"
+
 // vim: et sw=4:
