@@ -1,7 +1,7 @@
 /*
  *  fileresourcecreator.h  -  interactively create a file system resource
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2020-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -9,8 +9,7 @@
 #pragma once
 
 #include "resourcecreator.h"
-
-#include <KAlarmCal/KACalendar>
+#include "kalarmcalendar/kacalendar.h"
 
 class FileResourceCreator : public ResourceCreator
 {
@@ -25,5 +24,4 @@ private:
     bool createSingleFileResource();
 };
 
-
 // vim: et sw=4:
